==> refcomp-entities-1.6-sources.jar: fr/inra/refcomp/entities/AgentSkill.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface AgentSkill extends BusinessEntity {

    String EXT_AGENTSKILL = "AgentSkill";

    String FIELD_AGENTSKILL_COMMENT = "comment";

    String FQ_FIELD_AGENTSKILL_COMMENT = EXT_AGENTSKILL + ".comment";

    ElementField ELEMENT_FIELD_AGENTSKILL_COMMENT = new ElementField(FQ_FIELD_AGENTSKILL_COMMENT);

    String FIELD_AGENTSKILL_NATURE = "nature";

    String FQ_FIELD_AGENTSKILL_NATURE = EXT_AGENTSKILL + ".nature";

    ElementField ELEMENT_FIELD_AGENTSKILL_NATURE = new ElementField(FQ_FIELD_AGENTSKILL_NATURE);

    String FIELD_AGENTSKILL_TECHNICALSKILL = "technicalSkill";

    String FQ_FIELD_AGENTSKILL_TECHNICALSKILL = EXT_AGENTSKILL + ".technicalSkill";

    ElementField ELEMENT_FIELD_AGENTSKILL_TECHNICALSKILL = new ElementField(FQ_FIELD_AGENTSKILL_TECHNICALSKILL);

    String FIELD_AGENTSKILL_DOMAINSKILL = "domainSkill";

    String FQ_FIELD_AGENTSKILL_DOMAINSKILL = EXT_AGENTSKILL + ".domainSkill";

    ElementField ELEMENT_FIELD_AGENTSKILL_DOMAINSKILL = new ElementField(FQ_FIELD_AGENTSKILL_DOMAINSKILL);

    String FIELD_AGENTSKILL_FREQUENCY = "frequency";

    String FQ_FIELD_AGENTSKILL_FREQUENCY = EXT_AGENTSKILL + ".frequency";

    ElementField ELEMENT_FIELD_AGENTSKILL_FREQUENCY = new ElementField(FQ_FIELD_AGENTSKILL_FREQUENCY);

    String FIELD_AGENTSKILL_AGENT = "agent";

    String FQ_FIELD_AGENTSKILL_AGENT = EXT_AGENTSKILL + ".agent";

    ElementField ELEMENT_FIELD_AGENTSKILL_AGENT = new ElementField(FQ_FIELD_AGENTSKILL_AGENT);

    String getComment();

    void setComment(String comment);

    String getNature();

    void setNature(String nature);

    String getTechnicalSkill();

    void setTechnicalSkill(String technicalSkill);

    String getDomainSkill();

    void setDomainSkill(String domainSkill);

    String getFrequency();

    void setFrequency(String frequency);

    String getAgent();

    void setAgent(String agent);

} //AgentSkill

==> refcomp-entities-1.7-sources.jar: fr/inra/refcomp/entities/AgentSkill.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface AgentSkill extends BusinessEntity {

    String EXT_AGENTSKILL = "AgentSkill";

    String FIELD_AGENTSKILL_COMMENT = "comment";

    String FQ_FIELD_AGENTSKILL_COMMENT = EXT_AGENTSKILL + ".comment";

    ElementField ELEMENT_FIELD_AGENTSKILL_COMMENT = new ElementField(FQ_FIELD_AGENTSKILL_COMMENT);

    String FIELD_AGENTSKILL_NATURE = "nature";

    String FQ_FIELD_AGENTSKILL_NATURE = EXT_AGENTSKILL + ".nature";

    ElementField ELEMENT_FIELD_AGENTSKILL_NATURE = new ElementField(FQ_FIELD_AGENTSKILL_NATURE);

    String FIELD_AGENTSKILL_TECHNICALSKILL = "technicalSkill";

    String FQ_FIELD_AGENTSKILL_TECHNICALSKILL = EXT_AGENTSKILL + ".technicalSkill";

    ElementField ELEMENT_FIELD_AGENTSKILL_TECHNICALSKILL = new ElementField(FQ_FIELD_AGENTSKILL_TECHNICALSKILL);

    String FIELD_AGENTSKILL_DOMAINSKILL = "domainSkill";

    String FQ_FIELD_AGENTSKILL_DOMAINSKILL = EXT_AGENTSKILL + ".domainSkill";

    ElementField ELEMENT_FIELD_AGENTSKILL_DOMAINSKILL = new ElementField(FQ_FIELD_AGENTSKILL_DOMAINSKILL);

    String FIELD_AGENTSKILL_FREQUENCY = "frequency";

    String FQ_FIELD_AGENTSKILL_FREQUENCY = EXT_AGENTSKILL + ".frequency";

    ElementField ELEMENT_FIELD_AGENTSKILL_FREQUENCY = new ElementField(FQ_FIELD_AGENTSKILL_FREQUENCY);

    String FIELD_AGENTSKILL_AGENT = "agent";

    String FQ_FIELD_AGENTSKILL_AGENT = EXT_AGENTSKILL + ".agent";

    ElementField ELEMENT_FIELD_AGENTSKILL_AGENT = new ElementField(FQ_FIELD_AGENTSKILL_AGENT);

    String getComment();

    void setComment(String comment);

    String getNature();

    void setNature(String nature);

    Nature getNature(boolean exceptionIfNotLoaded);

    void setNature(Nature nature);

    String getTechnicalSkill();

    void setTechnicalSkill(String technicalSkill);

    Skill getTechnicalSkill(boolean exceptionIfNotLoaded);

    void setTechnicalSkill(Skill technicalSkill);

    String getDomainSkill();

    void setDomainSkill(String domainSkill);

    Skill getDomainSkill(boolean exceptionIfNotLoaded);

    void setDomainSkill(Skill domainSkill);

    String getFrequency();

    void setFrequency(String frequency);

    Frequency getFrequency(boolean exceptionIfNotLoaded);

    void setFrequency(Frequency frequency);

    String getAgent();

    void setAgent(String agent);

    Agent getAgent(boolean exceptionIfNotLoaded);

    void setAgent(Agent agent);

} //AgentSkill
